TransRInteraction
=================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: TransRInteraction
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~TransRInteraction.relation_shape

   .. rubric:: Methods Summary

   .. autosummary::

      ~TransRInteraction.func

   .. rubric:: Attributes Documentation

   .. autoattribute:: relation_shape

   .. rubric:: Methods Documentation

   .. automethod:: func
